Structs
Enums
- Monetary
Amount Error - An Error type you might use for safe divisions, negative sqrt, etc.
- Monetary
Amount Parse Error - Money
Stats Error
Traits
Functions
- convert_
vec_ f64_ to_ vec_ decimal - parse_
amount - parse_
amount_ opt - parse_
price - ratio_
div - Helper for dividing 2 MonetaryAmounts if we want a dimensionless ratio: e.g. (x-mean)/stdev is dimensionless. We wrap it in Dimensionless.
- segment_
by - simple_
linear_ regression - Return (slope, intercept) as (Dimensionless, Dimensionless).
In practice, if
xis dimensionless butyis currency, slope has currency dimension. For simplicity, we make them both dimensionless here, or you can define a separate approach.